@@ -7,22 +7,29 @@ class ElastalertWebhook(WebhookBase):
 
     def incoming(self, query_string, payload):
 
-        # Default parameters
-        print(payload)
-
-        environment = 'Production'
-        res = payload['event']
-        event = res['eventName']
-        severity =res['severity'].lower()
-        group ='Elastalert'
-        text = res['mesage']
-        #text = res['description']
-        tags = []
-        attributes = {}
-        origin = res['resourceXpath']
+        try:
+            # Default parameters
+            print("payload: "+str(payload))
+            resource = payload['kubernetes']['pod_name']
+            environment = 'Production'
+            res = payload['event']
+            event = res['eventName']
+            severity =res['severity'].lower()
+            group ='Elastalert'
+            text = res['message']
+            tags = []
+            attributes = {}
+            createTime = payload['@timestamp']
+            try:
+                origin = res['resourceXpath']
+            except Exception as e:
+                print("origin not defined")
+                origin = ' '
+        except Exception as e:
+            print("Error reading payload: "+str(e)) 
 
         return Alert(
-            resource = 'k8s',
+            resource = resource,
             event = event,
             severity = severity,
             service = ['example.com'],
@@ -30,6 +37,7 @@ class ElastalertWebhook(WebhookBase):
             text = text,
             tags = tags,
             origin = origin,
+            createTime = createTime,
             attributes = attributes,
             environment = environment
         #     environment=payload.get('environment', environment),
